@@ -1,12 +1,21 @@
 package Sah::Schema::color::ansi256;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Color'; # DIST
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [int => {
     summary => 'ANSI-256 color, an integer number from 0-255',
     min => 0,
     max => 255,
+    examples => [
+        {data=>  0, valid=>1},
+        {data=>255, valid=>1},
+        {data=>256, valid=>0},
+        {data=>'black'  , valid=>0}, # not supported yet
+        {data=>'foo'    , valid=>0},
+    ],
 }, {}];
 
 1;
@@ -24,7 +33,7 @@ Sah::Schema::color::ansi256 - ANSI-256 color, an integer number from 0-255
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::color::ansi256 (from Perl distribution Sah-Schemas-Color), released on 2019-11-29.
+This document describes version 0.006 of Sah::Schema::color::ansi256 (from Perl distribution Sah-Schemas-Color), released on 2020-03-02.
 
 =head1 HOMEPAGE
 
@@ -48,7 +57,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
