@@ -1,13 +1,22 @@
 package Sah::Schema::color::rgb24;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Color'; # DIST
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [str => {
     summary => 'RGB 24-digit color, a hexdigit e.g. ffcc00', # XXX also allow other forms
     match => qr/\A[0-9A-Fa-f]{6}\z/,
     'x.completion' => ['colorname'],
     'x.perl.coerce_rules' => ['From_str::rgb24_from_colorname_X_or_code'],
+    examples => [
+        {data=>'000000' , valid=>1, res=>'000000'},
+        {data=>'black'  , valid=>1, res=>'000000'},
+        {data=>'FFffcc' , valid=>1, res=>'ffffcc'},
+        {data=>'#FFffcc', valid=>1, res=>'ffffcc'},
+        {data=>'foo'    , valid=>0},
+    ],
 }, {}];
 
 1;
@@ -25,7 +34,7 @@ Sah::Schema::color::rgb24 - RGB 24-digit color, a hexdigit e.g. ffcc00
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2019-11-29.
+This document describes version 0.006 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2020-03-02.
 
 =head1 DESCRIPTION
 
@@ -63,7 +72,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
